// Copyright 2022 ESRI
//
// All rights reserved under the copyright laws of the United States
// and applicable international laws, treaties, and conventions.
//
// You may freely redistribute and use this sample code, with or
// without modification, provided you include the original copyright
// notice and use restrictions.
//
// See the Sample code usage restrictions document for further information.
//

#include "Display_an_mmpk.h"

#include "MapQuickView.h"

#include "MobileMapPackage.h"
#include "Error.h"


using namespace Esri::ArcGISRuntime;

Display_an_mmpk::Display_an_mmpk(QObject* parent /* = nullptr */):
    QObject(parent)
{
}

Display_an_mmpk::~Display_an_mmpk()
{
}

MapQuickView* Display_an_mmpk::mapView() const
{
    return m_mapView;
}

// Set the view (created in QML)
void Display_an_mmpk::setMapView(MapQuickView* mapView)
{
    if (!mapView || mapView == m_mapView)
    {
        return;
    }

    m_mapView = mapView;

    setupMapFromMmpk();

    emit mapViewChanged();

}

void Display_an_mmpk::setupMapFromMmpk()
{
    // Instantiate a MobileMapPackage object and establish the path to the MMPK file.
    MobileMapPackage* m_mobileMapPackage = new MobileMapPackage("<PATH_TO_MMPK_FILE>/MahouRivieraTrails.mmpk", this);

    // Use connect to signal when the package is done loading so that m_mapView can be set to the first map (0).
    // Check that the mmpk file has loaded correctly.
    connect(m_mobileMapPackage, &MobileMapPackage::doneLoading, this, [m_mobileMapPackage, this](Error error)
    {
        // Check that the mmpk file has loaded correctly
        if (!error.isEmpty())
        {
            qDebug() << "Error:" << error.message()<< error.additionalMessage();
            return;
        }

        // Get the first map in the list of maps, and set the map on the map view to display.
        // This could be set to any map in the list.
        m_mapView->setMap(m_mobileMapPackage->maps().at(0));
    });

    m_mobileMapPackage->load();
}


